@@ -4,6 +4,7 @@ from ensmallen import Graph, express_measures
 import numpy as np
 import pandas as pd
 import time
+import json
 from userinput.utils import must_be_in_set
 from tqdm.auto import trange, tqdm
 from embiggen.utils.abstract_models.list_formatting import format_list
@@ -1259,8 +1260,13 @@ class AbstractClassifierModel(AbstractModel):
         cache_path="{cache_dir}/{self.task_name()}/{graph.get_name()}/holdout_{holdout_number}/{self.model_name()}/{self.library_name()}/{_hash}.csv.gz",
         cache_dir="experiments",
         enable_cache_arg_name="enable_cache",
-        args_to_ignore=["verbose", "smoke_test",
-                        "train_of_interest", "test_of_interest", "train", ],
+        args_to_ignore=[
+            "verbose",
+            "smoke_test",
+            "train_of_interest",
+            "test_of_interest",
+            "train",
+        ],
         capture_enable_cache_arg_name=True,
         use_approximated_hash=True
     )
@@ -1278,6 +1284,7 @@ class AbstractClassifierModel(AbstractModel):
         random_state: int,
         holdout_number: int,
         evaluation_schema: str,
+        holdouts_kwargs: Dict[str, Any],
         features_names: List[str],
         features_parameters: Dict[str, Any],
         **validation_kwargs
@@ -1333,19 +1340,20 @@ class AbstractClassifierModel(AbstractModel):
         model_performance["nodes_number"] = graph.get_number_of_nodes()
         model_performance["edges_number"] = graph.get_number_of_directed_edges()
         model_performance["evaluation_schema"] = evaluation_schema
+        model_performance["holdouts_kwargs"] = json.dumps(holdouts_kwargs)
         model_performance["use_subgraph_as_support"] = use_subgraph_as_support
 
-        model_parameters = pd.DataFrame(dict(), index=model_performance.index)
-        features_parameters = pd.DataFrame(dict(), index=model_performance.index)
+        df_model_parameters = pd.DataFrame(dict(), index=model_performance.index)
+        df_features_parameters = pd.DataFrame(dict(), index=model_performance.index)
 
         for parameter_name, parameter_value in self.parameters().items():
             if isinstance(parameter_value, (list, tuple)):
                 parameter_value = str(parameter_value)
-            model_parameters[parameter_name] = parameter_value
+            df_model_parameters[parameter_name] = parameter_value
 
-        model_parameters.columns = [
-            ["model_parameters"] * len(model_parameters.columns),
-            model_parameters.columns
+        df_model_parameters.columns = [
+            ["model_parameters"] * len(df_model_parameters.columns),
+            df_model_parameters.columns
         ]
 
         model_performance["features_names"] = format_list(
@@ -1353,7 +1361,7 @@ class AbstractClassifierModel(AbstractModel):
         )
 
         for parameter, value in features_parameters.items():
-            if parameter in features_parameters.columns:
+            if parameter in df_features_parameters.columns:
                 raise ValueError(
                     "There has been a collision between the parameters used in "
                     "one of the embedding models and the parameter "
@@ -1361,18 +1369,18 @@ class AbstractClassifierModel(AbstractModel):
                     f"The parameter that has caused the collision is {parameter}. "
                     "Please do change the name of the parameter in your model."
                 )
-            features_parameters[parameter] = str(value)
+            df_features_parameters[parameter] = str(value)
 
-        features_parameters.columns = [
-            ["features_parameters"] * len(features_parameters.columns),
-            features_parameters.columns
+        df_features_parameters.columns = [
+            ["features_parameters"] * len(df_features_parameters.columns),
+            df_features_parameters.columns
         ]
 
         model_performance = pd.concat(
             [
                 model_performance,
-                model_parameters,
-                features_parameters
+                df_model_parameters,
+                df_features_parameters
             ],
             axis=1
         )
@@ -1388,9 +1396,6 @@ class AbstractClassifierModel(AbstractModel):
             "verbose",
             "smoke_test",
             "number_of_holdouts",
-            "time_required_to_compute_constant_node_features",
-            "time_required_to_compute_constant_node_type_features",
-            "time_required_to_compute_constant_edge_features"
         ],
         capture_enable_cache_arg_name=False,
         use_approximated_hash=True
@@ -1581,6 +1586,7 @@ class AbstractClassifierModel(AbstractModel):
                 random_state=random_state,
                 holdout_number=holdout_number,
                 evaluation_schema=evaluation_schema,
+                holdouts_kwargs=holdouts_kwargs,
                 enable_cache=enable_cache,
                 features_names=features_names,
                 features_parameters=features_parameters,
@@ -1750,7 +1756,7 @@ class AbstractClassifierModel(AbstractModel):
 
         # Retrieve the set of provided automatic features names
         # so we can put them in the report.
-        features_names = {
+        features_names = list({
             feature.model_name()
             for features in (
                 node_features
@@ -1765,7 +1771,7 @@ class AbstractClassifierModel(AbstractModel):
             )
             for feature in features
             if issubclass(feature.__class__, AbstractEmbeddingModel)
-        }
+        })
 
         # We normalize and/or compute the node features, having
         # the care of skipping the features that induce bias when
